@@ -7,22 +7,22 @@ from flask import Flask, request
 
 from .db import Db
 from .exceptions import LargePayloadExc
-
-LIMIT = 1000
+from .policy import QUERY_LIMIT
 
 
 def create_app(db: Db):
     """Backend for swh-scanner, implementing the /known endpoint of the
-       Software Heritage Web API"""
+    Software Heritage Web API"""
     app = Flask(__name__)
 
     @app.route("/api/1/known/", methods=["POST"])
     def known():
         swhids = request.get_json()
 
-        if len(swhids) > LIMIT:
+        if len(swhids) > QUERY_LIMIT:
             raise LargePayloadExc(
-                f"The maximum number of SWHIDs this endpoint can receive is {LIMIT}"
+                f"The maximum number of SWHIDs this endpoint can receive is"
+                f"{QUERY_LIMIT}"
             )
 
         cur = db.conn.cursor()
@@ -35,7 +35,6 @@ def create_app(db: Db):
 
 
 def run(host: str, port: int, db: Db):
-    """Serve the local database
-    """
+    """Serve the local database"""
     app = create_app(db)
     app.run(host, port, debug=True)
