@@ -1,4 +1,4 @@
-# Copyright (C) 2020  The Software Heritage developers
+# Copyright (C) 2020-2021  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -10,7 +10,7 @@ import shutil
 import sys
 
 import aiohttp
-from aioresponses import aioresponses  # type: ignore
+from aioresponses import aioresponses
 import pytest
 
 from swh.model.cli import model_of_dir
@@ -77,7 +77,7 @@ def source_tree(test_sample_folder):
 @pytest.fixture(scope="function")
 def big_source_tree(tmp_path):
     """Generate a model.from_disk.Directory from a "big" temporary directory
-       (more than 1000 nodes)
+    (more than 1000 nodes)
     """
     # workaround to avoid a RecursionError that could be generated while creating
     # a large number of directories
